from tkinter import *
from tkinter.messagebox import *
from tkinter.filedialog import *
from pyextension.tkinter.value import *
import pickle
import time

def askvalue(title='', msg='', args=(0, 100)):
    tk = Tk()
    tk.title(title)
    tk.resizable(0, 0)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).pack()
    if type(args[0]) == type(0):
        sb = Scale(tk, from_=args[0], to=args[1])
    elif type(args[0]) == type('0'):
        sb = Spinbox(tk, values=args, wrap=True)
    else:
        raise TypeError('%s\'s items must be int or string')
    sb.pack()
    Button(tk, text='OK', command=tk.quit).pack()
    # Window
    tk.mainloop()
    # Mainloop
    get = sb.get()
    tk.destroy()
    return get
# Askvalue
def askitem(title='', msg='', items=[], number=1, normal=0):
    tk = Tk()
    tk.title(title)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).place(relx=0.5, rely=0.05, relwidth=1, relheight=0.1, anchor='center')#, selectmode='multiple')
    lb = Listbox(tk)
    lb.place(relx=0.5, rely=0.5, relwidth=0.8, relheight=0.8, anchor='center')
    lb.selection_set(normal)
    Button(tk, text='OK', command=tk.quit).place(relx=0.5, rely=0.95, relwidth=1, relheight=0.1, anchor='center')
    # Window
    for x in range(0, len(items)):
        lb.insert('end', items[x])
    # Load
    tk.mainloop()
    # Mainloop
    finish = False
    get = []
    while not finish:
        tk.mainloop()
        for x in range(0, len(items)):
            if lb.selection_includes(x) == 1:
                get.append(x)
        # Get
        if len(get) == number:
            finish = True
        else:
            showinfo('', 'Choosen items must be %s item(s)' % number)
            get = []
    # Check & Get
    tk.destroy()
    return get
# Askitem
def askyesnocancel(title='', msg=''):
    tk = Tk()
    tk.title(title)
    tk.resizable(0, 0)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).grid(column=0, row=0, columnspan=4)
    b1 = Button(tk, text='Cancel')
    b1.grid(column=0, row=1)
    b2 = Button(tk, text='No')
    b2.grid(column=2, row=1)
    b3 = Button(tk, text='Yes')
    b3.grid(column=3, row=1)
    # Tkinter
    b1.bind('<Button-1>', s1)
    b2.bind('<Button-1>', s2)
    b3.bind('<Button-1>', s3)
    # Bind
    while AV.finish == '':
        tk.update()
        time.sleep(0.01)
    # Mainloop
    tk.destroy()
    return AV.finish
# Askyesnocancel
def askanswer(title='', msg=''):
    tk = Tk()
    tk.title(title)
    tk.resizable(0, 0)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).pack()
    entry = Entry(tk, width=30)
    entry.pack()
    Button(tk, text='Finish', command=tk.quit).pack()
    # Window
    tk.mainloop()
    # Mainloop
    get = entry.get()
    tk.destroy()
    return get
# Askanswer
def controlboard(title='', msg='', item=[('scale', '', 1, 100), ('listbox', '', [1, 2, 3])]):
    tk = Tk()
    tk.title(title)
    tk.minsize(width=100, height=100)
    # Tkinter
    text = Text(tk)
    text.place(relx=0.5, rely=0.5, relwidth=1, relheight=1, anchor='center')
    # Text
    if msg != '':
        text.insert('end', msg)
        text.insert('end', '\n')
    # Label
    window = []
    window_list = []
    for x in item:
        if x[0] == 'scale':
            window.append(Scale(tk, from_=x[2], to=x[3], orient='horizontal'))
            window_list.append('scale')
        elif x[0] == 'listbox':
            window.append(Listbox(tk))
            window_list.append('listbox')
            for y in x[2]:
                window[-1].insert('end', y)
    for x in range(0, len(item)):
        text.insert('end', item[x][1])
        text.insert('end', '\n')
        text.window_create('end', window=window[x])
        text.insert('end', '\n')
    # Scale & Listbox
    button = Button(tk, text='Finish', command=tk.quit)
    text.window_create('end', window=button)
    # Button
    text.config(state='disabled')
    # Window
    tk.mainloop()
    # Mainloop
    result = []
    for x in (0, len(window) - 1):
        if window_list[x] == 'scale':
            result.append(window[x].get())
        elif window_list[x] == 'listbox':
            for y in range(0, len(item[x][2])):
                if window[x].selection_includes(y) == 1:
                    result.append(item[x][2][y])
                    break
            if len(result) < x + 1:
                result.append(item[x][2][0]
                              )
        else:
            raise SystemExit
    tk.destroy()
    return result
# Controlboard
def singlechoice(title='', msg='', args=('a', 'b', 'c')):
    tk = Tk()
    tk.title(title)
    tk.resizable(0, 0)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).pack()
    window = []
    v = StringVar()
    for x in args:
        window.append(Radiobutton(tk, text=x, variable=v, value=x))
    for x in window:
        x.pack()
    Button(tk, text='Finish', command=tk.quit).pack()
    # Window
    tk.mainloop()
    # Mainloop
    get = v.get()
    tk.destroy()
    return get
# Singlechoice
def singlechoices(title='', msg='', args=(('a', 'b', 'c'), ('e', 'f', 'g'))):
    tk = Tk()
    tk.title(title)
    tk.resizable(0, 0)
    # Tkinter
    if msg != '':
        Label(tk, text=msg).pack()
    # Label
    window = []
    value_list = []
    lf_list = []
    times = 0
    for x in args:
        value_list.append(StringVar())
        # Value
        lf_list.append(LabelFrame(tk, text=str(times + 1)))
        # LabelFrame
        for y in x:
            window.append(Radiobutton(lf_list[times], text=y, variable=value_list[times], value=y))
        # Tkinter
        times += 1
    for x in window:
        x.pack(side='left')
    for x in lf_list:
        x.pack()
    # Checkbutton
    Button(tk, text='Finish', command=tk.quit).pack()
    # Button
    # Window
    tk.mainloop()
    # Mainloop
    get = []
    for x in value_list:
        get.append(x.get())
    tk.destroy()
    return get
# Singlechoices
def fastusefile(mode='open', filetypes=[('TXT', '.txt'), ('PY', '.py')], usemode=None, savethings=None):
    if mode == 'open':
        location = askopenfilename(filetypes=filetypes)
        if usemode == None:
            file = open(location)
            text = file.read()
            file.close()
            return text
        elif usemode == 'rb':
            file = open(location, 'rb')
            text = pickle.load(file)
            file.close()
            return text
        else:
            raise ValueError('usemode cannot be %s' % usemode)
    elif mode == 'save':
        location = asksaveasfilename(filetypes=filetypes)
        if usemode == 'w' or usemode == None:
            file = open(location, 'w')
            file.write(savethings)
            file.close()
        elif usemode == 'wb':
            file = open(location, 'wb')
            pickle.dump(savethings, file)
            file.close()
        else:
            raise ValueError('usemode cannot be %s' % usemode)
# Fastusefile
def create(tkinter_attribute, mode='menu', args=[('1', '<function>')], AddToTkinter=(False, 'grid', 0, 0, 0, 0, 'center'), note='''Args of option menu only takes strings, likes: arg=['a', 'b', 'c']'''):
    tk = tkinter_attribute
    if mode == 'menu':
        a = Menu(tk)
        for x in args:
            a.add_command(label=x[0], command=x[1])
        if AddToTkinter[0] == True:
            tk.config(menu=a)
        return a
    elif mode == 'option menu':
        v = StringVar()
        a = 'OptionMenu(tk, v, '
        for x in arg:
            a = a + '\'' + x + '\''
            if x != args[-1]:
                a = a + ', '
        a = a + ')'
        b = exec(a)
        if AddToTkinter[0] == True:
            if AddToTkinter[1] == 'pack':
                b.pack()
            elif AddToTkinter[1] == 'grid':
                if AddToTkinter[4] == 0:
                    AddToTkinter[4] = 1
                if AddToTkinter[5] == 0:
                    AddToTkinter[5] = 1
                if AddToTkinter[6] == 'center':
                    AddToTkinter[6] = 'w'
                b.grid(column=AddToTkinter[2], row=AddToTkinter[3],
                       columnspan=AddToTkinter[4], rowspan=AddToTkinter[5],
                       sticky=AddToTkinter[6])
            elif AddToTkinter[1] == 'place':
                if AddToTkinter[4] != 0 and AddToTkinter[5] != 0:
                    b.place(relx=AddToTkinter[2], rely=AddToTkinter[3],
                            relwidth=AddToTkinter[4], relheight=AddToTkinter[5],
                            anchor=AddToTkinter[6])
                elif AddToTkinter[4] == 0 and AddToTkinter[5] == 0:
                    b.place(relx=AddToTkinter[2], rely=AddToTkinter[3],
                            anchor=AddToTkinter[6])
                else:
                    raise ValueError('Both relwidth and relheight must be 0 or not 0')
        return b
# Create



import sys
if sys.version_info[0] != 3 or sys.version_info[1] < 10:
    raise SystemExit('Python version too low, at least Python 3.10 can use this module')

from math import *
import cmath as c

def run(mode='+', a=0, b=0):
    if a == 'pi':
        a = pi
    if b == 'pi':
        b = pi
    # pi
    if a == 'e':
        a = e
    if b == 'e':
        b = e
    # e
    if a == 'tau':
        a = tau
    if b == 'tau':
        b = tau
    # tau
    if a == 'inf':
        a = float('inf')
    if b == 'inf':
        b = float('inf')
    # inf
    if a == '-inf':
        a = float('-inf')
    if b == '-inf':
        b = float('-inf')
    # -inf
    if a == 'nan' or a == 'NaN':
        a = nan
    if b == 'nan' or b == 'NaN':
        b = nan
    # nan
    match mode:
        case '+':
            result = a + b
        case '-':
            result = a - b
        case '*':
            result = a * b
        case '/':
            result = a / b
        case '//':
            result = a // b
        case '...':
            result = a % b
        case '%':
            result = a % b
        # Operations
        case '>':
            if a > b:
                result = True
            else:
                result = False
        case '<':
            if a < b:
                result = True
            else:
                result = False
        case '==':
            if a == b:
                result = True
            else:
                result = False
        case '!=':
            if a != b:
                result = True
            else:
                result = False
        case '>=':
            if a >= b:
                result = True
            else:
                result = False
        case '<=':
            if a <= b:
                result = True
            else:
                result = False
        # Compare
        case '!':
            x = 1
            for y in range(1, a + 1):
                x = x * y
            result = x
        case '^':
            result = a ** b
        case 'square root':
            result = sqrt(a)
        case 'sqrt()':
            result = sqrt(a)
        # Power
        case 'exp()':
            result = exp(a)
        case 'exp1()':
            result = exp1(a)
        # Power And Logarithmic Functions
        case 'cos()':
            result = cos(a)
        case 'tan()':
            result = tan(a)
        case 'sin()':
            result = sin(a)
        case 'acos()':
            result = acos(a)
        case 'atan()':
            result = atan(a)
        case 'asin()':
            result = asin(a)
        case 'dist()':
            result = dist(a)
        case 'hypot()':
            result = hypot(a)
        # Trigonometric Function
        case 'cosh()':
            result = cosh(a)
        case 'tanh()':
            result = tanh(a)
        case 'sinh()':
            result = sinh(a)
        case 'acosh()':
            result = acosh(a)
        case 'atanh()':
            result = atanh(a)
        case 'asinh()':
            result = asinh(a)
        # Hyperbolic Functions
        case 'Degrees()':
            result = degrees(a)
        case 'degrees()':
            result = degrees(a)
        case 'Radians()':
            result = radians(a)
        case 'radians()':
            result = radians(a)
        # Angular Conversion
        case 'abs()':
            result = abs(a)
        # Else
        case 'Int / Float':
            if type(a) == type(1):
                result = float(a)
            elif type(a) == type(1.5):
                result = int(a)
            else:
                raise TypeError(''' 'Int / Float' object's argument must be int or float ''')
        case 'int / float':
            if type(a) == type(1):
                result = float(a)
            elif type(a) == type(1.5):
                result = int(a)
            else:
                raise TypeError(''' 'Int / Float' object's argument must be int or float ''')
        case 'Type':
            result = type(a)
        case 'type':
            result = type(a)
        # Type
        case _:
            raise AttributeError(''' 'run' object has no attribute '%s' ''' % mode)
    return result

def crun(mode, a, b):
    if a == 'pi':
        a = c.pi
    if b == 'pi':
        b = c.pi
    # pi
    if a == 'e':
        a = c.e
    if b == 'e':
        b = c.e
    # e
    if a == 'tau':
        a = c.tau
    if b == 'tau':
        b = c.tau
    # tau
    if a == 'inf':
        a = float('inf')
    if b == 'inf':
        b = float('inf')
    # inf
    if a == '-inf':
        a = float('-inf')
    if b == '-inf':
        b = float('-inf')
    # -inf
    if a == 'nan' or a == 'NaN':
        a = c.nan
    if b == 'nan' or b == 'NaN':
        b = c.nan
    # nan
    match mode:
        case 'cos()':
            return c.cos(a)
        case 'tan()':
            return c.tan(a)
        case 'sin()':
            return c.sin(a)
        case 'acos()':
            return c.cos(a)
        case 'atan()':
            return c.tan(a)
        case 'asin()':
            return c.sin(a)
        # Trigonometric Function
        case 'cosh()':
            return c.cos(a)
        case 'tanh()':
            return c.tan(a)
        case 'sinh()':
            return c.sin(a)
        case 'acosh()':
            return c.cos(a)
        case 'atanh()':
            return c.tan(a)
        case 'asinh()':
            return c.sin(a)
        # Hyperbolic Functions
        case _:
            raise AttributeError(''' 'crun' object has no attribute '%s' ''' % mode)

def mean(mode=''):
    match mode:
        case '+':
            message = 'Find the sum of A and B, indicating A plus B'
        case '-':
            message = 'Find the difference between A and B, which means A minus B'
        case '*':
            message = 'Find the product of A and B, representing A times B'
        case '/':
            message = 'The quotient of A and B, which means A divided by B'
        case '//':
            message = 'Find the integer part of a divided by B'
        case '...':
            message = 'Find the remainder of a divided by B'
        case '%':
            message = 'Find the remainder of a divided by B'
        # Operations
        case '>':
            message = 'Find whether A is greater than B. If yes, return True; If not, False is returned'
        case '<':
            message = 'Find whether A is less than B. If yes, return true; If not, false is returned'
        case '==':
            message = 'Find whether A is equal to B. If yes, return true; If not, false is returned'
        case '>=':
            message = 'Find whether A is greater than or equal to B. If yes, return true; If not, false is returned'
        case '<=':
            message = 'Find whether A is less than or equal to B. If yes, return true; If not, false is returned'
        case '!=':
            message = 'Find whether A is not equal to B. If yes, return true; If not, false is returned'
        # Compare
        case '!':
            message = 'Find the factorial of A'
        case '^':
            message = 'Seeking the b-th of a'
        case 'sqrt()':
            message = 'Find the square root of A'
        # Power
        case 'cos()':
            message = 'Return the cosine of x radians'
        case 'sin()':
            message = 'Return the sine of x radians'
        case 'tan()':
            message = 'Return the tangent of x radians'
        case 'acos()':
            message = 'Return the arc cosine of A, in radians'
        case 'asin()':
            message = 'Return the arc sine of A, in radians'
        case 'atan()':
            message = 'Return the arc tangent of A, in radians'
        case 'dist()':
            message = 'Return the Euclidean distance between two points A and B, \n each given as a sequence (or iterable) of coordinates. \n The two points must have the same dimension'
        case 'hypot()':
            message = '''Return the Euclidean norm,
sqrt(sum(A**2 for A in coordinates)).
This is the length of the vector from the origin to the point given by the coordinates.
For a two dimensional point (A, B),
this is equivalent to computing the hypotenuse of a right triangle using the Pythagorean theorem, sqrt(A*A + B*B)'''
        # Trigonometric Function
        case 'acosh()':
            message = 'Return the inverse hyperbolic cosine of A'
        case 'asinh()':
            message = 'Return the inverse hyperbolic sine of A'
        case 'atanh()':
            message = 'Return the inverse hyperbolic tangent of A'
        case 'cosh()':
            message = 'Return the hyperbolic cosine of A'
        case 'sinh()':
            message = 'Return the hyperbolic sine of A'
        case 'tanh()':
            message = 'Return the hyperbolic tangent of A'
        # Hyperbolic Functions
        case 'exp()':
            message = 'Return e raised to the power A, where e = 2.718281… is the base of natural logarithms. \n This is usually more accurate than math.e ** A or pow(math.e, A)'
        case 'expm1()':
            message = '''Return e raised to the power A, minus 1.
Here e is the base of natural logarithms.
For small floats A, the subtraction in exp(A) - 1 can result in a significant loss of precision;
the expm1() function provides a way to compute this quantity to full precision:

>>> from math import exp, expm1
>>> exp(1e-5) - 1  # gives result accurate to 11 places
1.0000050000069649e-05
>>> expm1(1e-5)    # result accurate to full precision
1.0000050000166668e-05'''
        # Power And Logarithmic Functions
        case 'Degrees()':
            message = 'Convert angle A from radians to degrees'
        case 'degrees()':
            message = 'Convert angle A from radians to degrees'
        case 'Radians()':
            message = 'Convert angle A from degrees to radians'
        case 'radians()':
            message = 'Convert angle A from degrees to radians'
        # Angular Conversion
        case 'abs()':
            message = 'Return the absolute value of a'
        # Else
        case 'Int / Float':
            message = 'Force integer A to be converted to decimal, or convert decimal A to integer ( Note: if the decimal part of A is 0, A will be converted to decimal x.0 )'
        case 'int / float':
            message = 'Force integer A to be converted to decimal, or convert decimal A to integer ( Note: if the decimal part of A is 0, A will be converted to decimal x.0 )'
        case 'Type':
            message = 'Returns the type of A, integer returns Int, decimal returns Float \n ( Note: if decimal part is 0, Int is returned )'
        case 'type':
            message = 'Returns the type of A, integer returns Int, decimal returns Float \n ( Note: if decimal part is 0, Int is returned )'
        # Type
        case _:
            raise AttributeError(''' 'mean' object has no attribute '%s' ''' % mode)

def list():
    a = '''
+, -, *, /, //, ..., %,
^, sqrt(), sqare root,
exp(), exp1(),
cos(), tan(), sin(),
acos(), atan(), asin(),
cosh(), tanh(), sinh(),
acosh(), atanh(), asinh(),
abs(),
Int / Float, Type
'''
    print(a)



from tkinter import *
from tkinter.messagebox import *
import time

class Timer():
    def __init__(self, window, mode='timer', arg=0):
        self.end = False
        self.tk = window
        self.mode = mode
        if mode == 'timer':
            self.window = Label(window, text=0)
        elif mode == 'down count':
            self.time = arg
            self.window = Label(window, text=self.time)
        elif mode == 'alarm clock':
            self.time = arg
        else:
            raise AttributeError(''' 'Time' object has no attribute '%s' ''' % mode)
    def timer(per1second):
        psecond = per1second % 100
        # Per 1 S
        second = per1second // 100
        while second >= 60:
            second -= 60
        # S
        minute = per1second // 100 // 60
        while minute >= 60:
            minute -= 60
        # Min
        hour = per1second // 100 // 60 // 60
        while hour >= 24:
            hour -= 24
        # H
        day = per1second // 100 // 60 // 60 // 24
        # D
        return '%s : %s : %s : %s : %s' % (day, hour, minute, second, psecond)
    def pack(self, side=None):
        if side != None:
            self.window.pack()
        else:
            self.window.pack(side=side)
    def grid(self, column=None, row=None, columnspan=1, rowspan=1, sticky=None):
        if column != None and row != None:
            if columnspan != 0 and rowspan != 0 and sticky == None:
                self.window.grid(column=column, row=row, columnspan=columnspan, rowspan=rowspan)
            elif columnspan != 0 and rowspan != 0 and sticky != None:
                self.window.grid(column=column, row=row, columnspan=columnspan, rowspan=rowspan, sticky=sticky)
            else:
                raise ValueError('Both columnspan and rowspan must be not 0')
        else:
            raise ValueError('Both column and row must be not None')
    def place(self, relx=None, rely=None, relwidth=None, relheight=None, anchor='center'):
        if relx != None and rely != None:
            if relwidth != None and relheight != None:
                self.window.place(relx=relx, rely=rely, relwidth=relwidth, relheight=relheight, anchor=anchor)
            else:
                self.window.place(relx=relx, rely=rely, anchor=anchor)
        else:
            raise ValueError('Both relx and rely must be not None')
    def mainloop(self):
        if self.mode == 'timer':
            per1second = 0
            while self.end != True:
                self.window.config(text=Timer.timer(per1second))
                self.tk.update()
                time.sleep(0.01)
                per1second += 1
        elif self.mode == 'down count':
            while self.time > 0:
                self.window.config(text=Timer.timer(self.time))
                self.tk.update()
                time.sleep(0.01)
                self.time -= 1
        elif self.mode == 'alarm clock':
            while self.time > 0:
                self.tk.update()
                time.sleep(0.01)
                self.time -= 1
    def stop(self):
        self.end == True



import sys
if sys.version_info[0] != 3 or sys.version_info[1] < 10:
    raise SystemExit('Python version too low, at least Python 3.10 can use this module')

from tkinter import *
from docx import *
from docx.shared import *

def add_text(text, attribute=Document(), mode=('normal', 'attribute', None), paragraph=(True, 'normal', None)):  # mode => text - return - argument ; paragraph => new - mode - argument
    if mode[1] == 'attribute':
        if paragraph[0] == True:
            match paragraph[1]:
                case 'normal':
                    p = attribute.add_paragraph('')
                case 'body':
                    p = attribute.add_paragraph('', style='Body Text')
                case 'bullet':
                    p = attribute.add_paragraph('', style='List Bullet')
                case 'number':
                    p = attribute.add_paragraph('', style='List Number')
                case _:
                    raise AttributeError('\'add_text - paragraph - mode\' object has no attribute \'%s\'' % paragraph[1])
        else:
            p = argument
        # Paragraph
        match mode[0]:
            case 'normal':
                p.add_run(text)
            case'normal':
                p.add_run(text)
            case 'bold':
                p.add_run(text).bold = True
            case 'italic':
                p.add_run(text).italic = True
            case 'underline':
                p.add_run(text).underline = True
            case 'deleteline':
                p.add_run(text).deleteline = True
            case 'outline':
                p.add_run(text).outline = True
            case 'imprint':
                p.add_run(text).imprint = True
            case 'emboss':
                p.add_run(text).emboss = True
            case 'double_strike':
                p.add_run(text).double_strike = True
            case 'rtl':
                p.add_run(text).rtl = True
            case 'shadow':
                p.add_run(text).shadow = True
            case 'size':
                p.add_run(text).size = Pt(mode[2])
            case 'subscript':
                p.add_run(text).subscript = True
            case 'superscript':
                p.add_run(text).subscript = True
            case _:
                raise AttributeError('\'add_text - run - mode\'object has no attribute \'%s\'' % mode[0])
        # Add Run
        return attribute
    elif mode[1] == 'list':
        p = []
        match mode[0]:
            case 'normal':
                p.append(text)
            case 'bold':
                p.append(['bold', text])
            case 'italic':
                p.append(['italic', text])
            case 'underline':
                p.append(['underline', text])
            case 'deleteline':
                p.append(['deleteline', text])
            case 'outline':
                p.append(['outline', text])
            case 'imprint':
                p.append(['imprint', text])
            case 'emboss':
                p.append(['emboss', text])
            case 'double_strike':
                p.append(['double strike', text])
            case 'rtl':
                p.append(['rtl', text])
            case 'shadow':
                p.append(['shadow', text])
            case 'size':
                p.append(['size', text, Pt(mode[2])])
            case 'subscript':
                p.append(['subscript', text])
            case 'superscript':
                p.append(['superscript', text])
            case _:
                raise AttributeError('\'add_text - run - mode\'object has no attribute \'%s\'' % mode[0])
        return p
    else:
        raise AttributeError('\'add_text\' has no attribute \'%s\'' % mode[1])

def add_heading(text, attribute=Document(), mode=(None), heading=(True, 'normal', None)):  # mode => argumet ; heading => new - mode - argument
    if heading[0] == True:
        match heading[1]:
            case 'normal':
                h = attribute.add_heading(text, 0)
            case _:
                raise AttributeError('\'add_heading - heading - mode\' object has no attribute \'%s\'' % heading[1])
    return attribute



text = {
    '__init__' : {
        'askvalue' : '''
askvalue(title='', msg='', arg=())
If args are two int,
it will create a window with a Spinbox that can choose number between two int.

If args are strings,
it will create a window with a Spinvox that can choose things in args.
''',
        'askitem' : '''
askitem(title='', msg='', items=[], number=1, normal=0)
It will create a tkinter window with title, msg
and a Listbox that can choose things in the items.

The number of the things can choose depends on argument : number
And ‘normal’ means if you do not do anythings before enter,
the choosen item will be the index 'normal' in list 'items'.
''',
        }
    }
def search(class_='__init__', function='askvalue'):
    print(text[class_][function])



from tkinter import *
from tkinter.filedialog import *
import pickle

word = {
    'a' : [
        'a',
        'able',
        'ability',
        'achivement',
        'again',
        'all',
        'alpha',
        'am',
        'an',
        'ant',
        'any',
        'angry',
        'anyone',
        'anybody',
        'anywhere',
        'apple',
        'apply',
        'application',
        'April',
        'are',
        'as',
        'aunt',
        'August',
        'awful',
        ''
        ],
    'b' : [
        'b',
        'bank',
        'base',
        'basic',
        'banana',
        'basket',
        'baseball',
        'basketball',
        'beach',
        'bit',
        'boom',
        'bring',
        'bridge',
        'bright',
        ''
        ],
    'c' : [
        'c',
        'car',
        'cake',
        'case',
        'cash',
        'canvas',
        'cabbage',
        'celebrate',
        'cell',
        'cute',
        ],
    'd' : [
        'd',
        'data',
        'date',
        'dance'
        'danger',
        'dangeons',
        ''
        ],
    'e' : [
        'e'
        ],
    'f' : [
        'f'
        ],
    'g' : [
        'g'
        ],
    'h' : [
        'h'
        ],
    'i' : [
        'i'
        ],
    'j' : [
        'j'
        ],
    'k' : [
        'k'
        ],
    'l' : [
        'l'
        ],
    'm' : [
        'm'
        ],
    'n' : [
        'n'
        ],
    'o' : [
        'o'
        ],
    'p' : [
        'p'
        ],
    'q' : [
        'q'
        ],
    'r' : [
        'r'
        ],
    's' : [
        's'
        ],
    't' : [
        't'
        ],
    'u' : [
        'u'
        ],
    'v' : [
        'v'
        ],
    'w' : [
        'w'
        ],
    'x' : [
        'x'
        ],
    'y' : [
        'y'
        ],
    'z' : [
        'z'
        ]
    }

def install():
    file = open('word bank.dat', 'wb')
    pickle.dump(word, file)
    file.close()

class Word():
    def __init__(self, value=None):
        if value == None:
            file = open('word bank.dat', 'rb')
            self.dic = pickle.load(file)
            file.close()
        elif type(value) == type({}):
            self.dic = value
        else:
            raise TypeError('value must be a dictionary type')
    def search(self, key):
        return self.dic[key]
    def get(self):
        return self.dic
    def insert(self, key, item=[], save=False):
        for x in item:
            self.dic[key] = self.dic[key].append(x)
        if save == True:
            file = open('word bank.dat', 'wb')
            pickle.dump(self.dic, file)
            file.close()
        return self.dic
    def change(self, key, item, save=False):
        if type(item) == type([]):
            self.dic[key] = item
        else:
            raise TypeError('Argument \'item\' must be list type')
        if save == True:
            file = open('word bank.dat', 'wb')
            pickle.dump(self.dic, file)
            file.close()
        return self.dic
    def delete(self, key, item, save=False):
        if type(item) == type(1):
            del self.dic[key][item]
        elif type(item) == type(''):
            times = 0
            try:
                while True:
                    if self.dic[key][times] == item:
                        del self.dic[key][times]
                        break
                    times += 1
            except IndexError:
                raise ValueError('No item \'%s\' in word bank.dat[%s]' % (item, key))
            return dic
        elif type(item) == type([]):
            for x in item:
                if type(x) == type(0):
                    del self.dic[key][x]
                elif type(x) == type(''):
                    times = 0
                    try:
                        while True:
                            if self.dic[key][times] == x:
                                del self.dic[key][times]
                                break
                            times += 1
                    except IndexError:
                        raise ValueError('No item \'%s\' in word bank.dat[%s]' % (x, key))
        else:
            raise TypeError('type \'item\' must be string or int')
        # Delete
        if save == True:
            file = open('word bank.dat', 'wb')
            pickle.dump(self.dic, file)
            file.close()
        return self.dic
    def save(self, location=None):
        if location == None:
            location = asksaveasfilename(filetypes=[('DAT', '.dat')])
        if location[-4] + location[-3] + location[-2] + location[-1] != '.dat':
            location = location + '.dat'
            print('Warning : Your location is not a dat file, we turned it to a dat file, please check the file if it not the shape you want.')
        file = open(location, 'wb')
        pickle.dump(self.dic, file)
        file.close()



import platform as p
import sys

def computer():
    print('===== %s =====' % p.node())
    print('''OS:
    %s''' % p.system())
    print('''Processor:
    %s''' % p.processor())
    print('''Machine:
    %s''' % p.machine())
    print('''Release:
    %s''' % p.release())
    print('''Platform:
    %s''' % p.platform())
    print('''Version:
    %s''' % p.version())

def python():
    print('===== Python ' + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + '.' + str(sys.version_info[2]) + ' =====')
    print('''Version : ''')
    print(4 * ' ',end='')
    print(sys.version)
    print('''Build :
    ''',end='')
    print(p.python_build())



from setuptools import *

setup(
    name = 'Python-Extension',
    version = '0.4.1',
    description = 'Python Extension Function',
    license = 'GPL',
    author = 'Yile Wang',
    packages = find_packages(),
    python_requires = '>=3.10',
    include_package_data = True
    )
